<?php
/**
 * Optics Theme Customizer.
 *
 * @package Optics
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function photolog_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

}
add_action( 'customize_register', 'photolog_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function photolog_customize_preview_js() {
	wp_enqueue_script( 'photolog_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'photolog_customize_preview_js' );

/**
 * Add a placeholder section to show users additional available options
 */
function photolog_customizer_upgrade_to_pro( $wp_customize ) {

	if ( photolog_is_pro() )
		return;

	$wp_customize->add_panel( 'theme_options', array(
        'title'     => esc_html__( 'Theme Options', 'photolog' ),
        'priority'  => 105
    ) );

	$wp_customize->add_setting( 'upgrade_option', array(
		'sanitize_callback' => 'esc_html'
	) );
	$wp_customize->add_control( 'upgrade_option', array() );

	$wp_customize->add_setting( 'photolog_section_fonts', array(
			'sanitize_callback' => 'esc_html'
	) );

	$wp_customize->add_section( 'photolog_section_fonts' , array(
	    'title' => __( 'Typography', 'photolog' ),
	    'description' => sprintf(
			esc_html__( '%s to enable additional fonts choices on your website.', 'photolog' ),
			sprintf(
				'<a href="%1$s" target="_blank">%2$s</a>',
				esc_url( photolog_get_pro_link() ),
				esc_html__( 'Upgrade to photolog Pro', 'photolog' )
			)
		),
		'panel'    => 'theme_options',
		'priority' => 5
	));

	// Heading Font Setting
	$wp_customize->add_setting( 'heading_font', array(
		'default'			=> '',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'esc_html'
	) );

	// Heading Font Control
	$wp_customize->add_control( 'heading_font', array(
		'label'             => esc_html__( 'Headings Font', 'photolog' ),
		'section'           => 'photolog_section_fonts',
		'type'              => 'text',
		'settings'          => 'heading_font',
		'description'       => '<select><option selected="selected" disabled="disabled"> ' . esc_html__( "Choose a Google font", "photolog" ) . '</option></select>',
		'priority'          => 6,
	) );

	// Body Font Setting
	$wp_customize->add_setting( 'body_font', array(
		'default'			=> '',
		'sanitize_callback' => 'esc_html'
	) );

	// Body Font Control
	$wp_customize->add_control( 'body_font', array(
		'label'             => esc_html__( 'Body Font', 'photolog' ),
		'section'           => 'photolog_section_fonts',
		'type'              => 'text',
		'settings'          => 'body_font',
		'description'       => '<select><option selected="selected" disabled="disabled"> ' . esc_html__( "Choose a Google font", "photolog" ) . '</option></select>',
		'priority'          => 7,
	) );

	$wp_customize->add_section( 'photolog_colors', array(
		'title'         => esc_html__( 'Color Scheme', 'photolog' ),
		'description' => sprintf(
			__( '%s to enable color palettes and individual section colors on your website.', 'photolog' ),
			sprintf(
				'<a href="%1$s" target="_blank">%2$s</a>',
				esc_url( photolog_get_pro_link() ),
				esc_html__( 'Upgrade to Optics Pro', 'photolog' )
			)
		),
		'priority'      => 10,
		'panel'         => 'theme_options'
	) );

	// Color Scheme Setting
	$wp_customize->add_setting( 'photolog_color', array(
		'default'           => 'default',
		'sanitize_callback' => 'esc_html'
	) );

	// Color Scheme Control
	$wp_customize->add_control( 'photolog_color', array(
		'label'             => esc_html__( 'Color Scheme', 'photolog' ),
		'section'           => 'photolog_colors',
		'type'              => 'text',
		'settings'          => 'photolog_color',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Choose a Color Scheme", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Default", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Beautiful", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Blossom", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Camo", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Dark", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Ice", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Oreo", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Splash", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Spring", "photolog" ) . '</option>
								</select>',
	) );

	/**
	 * Mega Menu
	 */
	$wp_customize->add_section( 'photolog_megamenu', array(
		'title'         => esc_html__( 'Mega Menu', 'photolog' ),
		'description' => sprintf(
			esc_html__( '%s to enable mega menu for your website.', 'photolog' ),
			sprintf(
				'<a href="%1$s" target="_blank">%2$s</a>',
				esc_url( photolog_get_pro_link() ),
				esc_html__( 'Upgrade to Optics Pro', 'photolog' )
			)
		),
		'priority'      => 10,
		'panel'         => 'theme_options'
	) );

	// Mega Menu Setting
	$wp_customize->add_setting( 'photolog_megamenu', array(
		'default'           => 'default',
		'sanitize_callback' => 'esc_html'
	) );

	// Mega Menu Control
	$wp_customize->add_control( 'photolog_megamenu', array(
		'label'             => esc_html__( 'Enable Mega Menu', 'photolog' ),
		'section'           => 'photolog_megamenu',
		'type'              => 'text',
		'settings'          => 'photolog_megamenu',
		'description'       => esc_html__( 'This converts existing Primary Menu to a Mega Menu.', 'photolog' ) . '<br/><select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "No", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Yes", "photolog" ) . '</option>
								</select>',
	) );

	/**
	 * Galleries
	 */
	$wp_customize->add_section( 'photolog_galleries', array(
		'title'         => esc_html__( 'Galleries', 'photolog' ),
		'description' => sprintf(
			esc_html__( '%s to enable galleries option for your website. The settings below apply to all galleries that you insert into your Posts and Pages.', 'photolog' ),
			sprintf(
				'<a href="%1$s" target="_blank">%2$s</a>',
				esc_url( photolog_get_pro_link() ),
				esc_html__( 'Upgrade to Optics Pro', 'photolog' )
			)
		),
		'priority'      => 10,
		'panel'         => 'theme_options'
	) );

	// Galleries Setting
	$wp_customize->add_setting( 'photolog_galleries_tm', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// Galleries Control
	$wp_customize->add_control( 'photolog_galleries', array(
		'label'             => esc_html__( 'Transition Mode', 'photolog' ),
		'section'           => 'photolog_galleries',
		'type'              => 'text',
		'settings'          => 'photolog_galleries_tm',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Slide", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Fade", "photolog" ) . '</option>
								</select>',
	) );

	// Galleries Setting
	$wp_customize->add_setting( 'photolog_galleries_ts', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// Galleries Control
	$wp_customize->add_control( 'photolog_galleries_ts', array(
		'label'             => esc_html__( 'Transition Speed', 'photolog' ),
		'section'           => 'photolog_galleries',
		'type'              => 'text',
		'settings'          => 'photolog_galleries_ts',
		'description'       => '<input type="text" disabled="disabled" value="5000" />',
	) );

	// Gallery Setting
	$wp_customize->add_setting( 'photolog_galleries_id', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// Gallery Control
	$wp_customize->add_control( 'photolog_galleries_id', array(
		'label'             => esc_html__( 'Image Download Icon', 'photolog' ),
		'section'           => 'photolog_galleries',
		'type'              => 'text',
		'settings'          => 'photolog_galleries_id',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Show", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Hide", "photolog" ) . '</option>
								</select>',
	) );

	// Gallery Setting
	$wp_customize->add_setting( 'photolog_galleries_ic', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// Gallery Control
	$wp_customize->add_control( 'photolog_galleries_ic', array(
		'label'             => esc_html__( 'Image Counter', 'photolog' ),
		'section'           => 'photolog_galleries',
		'type'              => 'text',
		'settings'          => 'photolog_galleries_ic',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Show", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Hide", "photolog" ) . '</option>
								</select>',
	) );

	// Gallery Setting
	$wp_customize->add_setting( 'photolog_galleries_t', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// Gallery Control
	$wp_customize->add_control( 'photolog_galleries_t', array(
		'label'             => esc_html__( 'Thumbnails', 'photolog' ),
		'section'           => 'photolog_galleries',
		'type'              => 'text',
		'settings'          => 'photolog_galleries_t',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Show", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Hide", "photolog" ) . '</option>
								</select>',
	) );

	// Gallery Setting
	$wp_customize->add_setting( 'photolog_galleries_ap', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// Gallery Control
	$wp_customize->add_control( 'photolog_galleries_ap', array(
		'label'             => esc_html__( 'Autoplay Option', 'photolog' ),
		'section'           => 'photolog_galleries',
		'type'              => 'text',
		'settings'          => 'photolog_galleries_ap',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Show", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Hide", "photolog" ) . '</option>
								</select>',
	) );

	// Gallery Setting
	$wp_customize->add_setting( 'photolog_galleries_f', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// Gallery Control
	$wp_customize->add_control( 'photolog_galleries_f', array(
		'label'             => esc_html__( 'Fullscreen Option', 'photolog' ),
		'section'           => 'photolog_galleries',
		'type'              => 'text',
		'settings'          => 'photolog_galleries_f',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Show", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Hide", "photolog" ) . '</option>
								</select>',
	) );

	// Gallery Setting
	$wp_customize->add_setting( 'photolog_galleries_z', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// Gallery Control
	$wp_customize->add_control( 'photolog_galleries_z', array(
		'label'             => esc_html__( 'Zoom Option', 'photolog' ),
		'section'           => 'photolog_galleries',
		'type'              => 'text',
		'settings'          => 'photolog_galleries_z',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Show", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Hide", "photolog" ) . '</option>
								</select>',
	) );


	/**
	 * Featured Content Slider
	 */
	$wp_customize->add_section( 'photolog_fcs', array(
		'title'         => esc_html__( 'Featured Content Slider', 'photolog' ),
		'description' => sprintf(
			esc_html__( '%s to enable featured content slider option for your website.', 'photolog' ),
			sprintf(
				'<a href="%1$s" target="_blank">%2$s</a>',
				esc_url( photolog_get_pro_link() ),
				esc_html__( 'Upgrade to Optics Pro', 'photolog' )
			)
		),
		'priority'      => 10,
		'panel'         => 'theme_options'
	) );

	// FCS Setting
	$wp_customize->add_setting( 'photolog_fcs_enable', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// FCS Control
	$wp_customize->add_control( 'photolog_fcs_enable', array(
		'label'             => esc_html__( 'Enable Slider', 'photolog' ),
		'section'           => 'photolog_fcs',
		'type'              => 'text',
		'settings'          => 'photolog_fcs_enable',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Yes", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "No", "photolog" ) . '</option>
								</select>',
	) );

	// FCS Setting
	$wp_customize->add_setting( 'photolog_fcs_st', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// FCS Control
	$wp_customize->add_control( 'photolog_fcs_st', array(
		'label'             => esc_html__( 'Slider Thumbnails', 'photolog' ),
		'section'           => 'photolog_fcs',
		'type'              => 'text',
		'settings'          => 'photolog_fcs_st',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Show", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Hide", "photolog" ) . '</option>
								</select>',
	) );

	// FCS Setting
	$wp_customize->add_setting( 'photolog_fcs_si', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// FCS Control
	$wp_customize->add_control( 'photolog_fcs_si', array(
		'label'             => esc_html__( 'Slider Items', 'photolog' ),
		'section'           => 'photolog_fcs',
		'type'              => 'text',
		'settings'          => 'photolog_fcs_si',
		'description'       => '<select>
									<option disabled="disabled"> ' . esc_html__( "1", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "2", "photolog" ) . '</option>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "3", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "4", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "5", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "6", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "7", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "8", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "9", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "10", "photolog" ) . '</option>
								</select>',
	) );

	// FCS Setting
	$wp_customize->add_setting( 'photolog_fcs_stm', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// FCS Control
	$wp_customize->add_control( 'photolog_fcs_stm', array(
		'label'             => esc_html__( 'Slider Transition Mode', 'photolog' ),
		'section'           => 'photolog_fcs',
		'type'              => 'text',
		'settings'          => 'photolog_fcs_stm',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Fade", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Slide", "photolog" ) . '</option>
								</select>',
	) );

	// FCS Setting
	$wp_customize->add_setting( 'photolog_fcs_sat', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// FCS Control
	$wp_customize->add_control( 'photolog_fcs_sat', array(
		'label'             => esc_html__( 'Slider Auto Start', 'photolog' ),
		'section'           => 'photolog_fcs',
		'type'              => 'text',
		'settings'          => 'photolog_fcs_sat',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Yes", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "No", "photolog" ) . '</option>
								</select>',
	) );

	// FCS Setting
	$wp_customize->add_setting( 'photolog_fcs_sh', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// FCS Control
	$wp_customize->add_control( 'photolog_fcs_sh', array(
		'label'             => esc_html__( 'Slider Height', 'photolog' ),
		'section'           => 'photolog_fcs',
		'type'              => 'text',
		'settings'          => 'photolog_fcs_sh',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Adaptive", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Fixed", "photolog" ) . '</option>
								</select>',
	) );

	// FCS Setting
	$wp_customize->add_setting( 'photolog_fcs_vl', array(
		'default'           => '',
		'sanitize_callback' => 'esc_html'
	) );

	// FCS Control
	$wp_customize->add_control( 'photolog_fcs_vl', array(
		'label'             => esc_html__( 'Vertical Layout', 'photolog' ),
		'section'           => 'photolog_fcs',
		'type'              => 'text',
		'settings'          => 'photolog_fcs_vl',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Yes", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "No", "photolog" ) . '</option>
								</select>',
	) );


	/**
	 * Custom CSS Section
	 */
	$wp_customize->add_section( 'custom_css', array(
		'title'         => esc_html__( 'Custom CSS', 'photolog' ),
		'description' => sprintf(
			__( '%s to enable Custom CSS on your website.', 'photolog' ),
			sprintf(
				'<a href="%1$s" target="_blank">%2$s</a>',
				esc_url( photolog_get_pro_link() ),
				esc_html__( 'Upgrade to Optics Pro', 'photolog' )
			)
		),
		'priority'      => 15,
		'panel'         => 'theme_options'
	) );

	// Custom CSS Setting
	$wp_customize->add_setting( 'css', array(
		'default'       => '',
		'sanitize_callback' => 'esc_html'
	) );

	// Custom CSS Control
	$wp_customize->add_control( 'css', array(
		'section'       => 'custom_css',
	) );

	$wp_customize->add_section( 'credits', array(
		'title'         => esc_html__( 'Footer Credits', 'photolog' ),
		'description' => sprintf(
			__( '%s to disable or add custom footer credits on your website.', 'photolog' ),
			sprintf(
				'<a href="%1$s" target="_blank">%2$s</a>',
				esc_url( photolog_get_pro_link() ),
				esc_html__( 'Upgrade to Optics Pro', 'photolog' )
			)
		),
		'priority'      => 20,
		'panel'         => 'theme_options'
	) );

	// Default Copyright Setting
	$wp_customize->add_setting( 'default_credits', array(
		'default'			=> 'show',
		'sanitize_callback' => 'esc_html'
	) );

	// Default Copyright Control
	$wp_customize->add_control( 'default_credits', array(
		'label'             => esc_html__( 'Default Footer Credits', 'photolog' ),
		'section'           => 'credits',
		'type'              => 'text',
		'settings'          => 'default_credits',
		'description'       => '<select>
									<option selected="selected" disabled="disabled"> ' . esc_html__( "Show", "photolog" ) . '</option>
									<option disabled="disabled"> ' . esc_html__( "Hide", "photolog" ) . '</option>
								</select>',

	) );

	// Custom Copyright Setting
	$wp_customize->add_setting( 'custom_credits', array(
			'sanitize_callback' => 'esc_html'
	) );

	// Custom Copyright Control
	$wp_customize->add_control( 'custom_credits', array(
		'label'             => esc_html__( 'Custom Footer Credits', 'photolog' ),
		'description'		=> esc_html__( 'Add your own credits', 'photolog' ) . 
								'<input type="text" disabled="disabled" />',
		'section'           => 'credits',
		'type'              => 'text',
		'settings'          => 'custom_credits',
	) );

}
add_action( 'customize_register', 'photolog_customizer_upgrade_to_pro' );

/**
 * Localize scripts for Customizer
 * @return [type] [description]
 */
function photolog_customizer_scripts() {

	if ( ! photolog_is_pro() ) {
		wp_enqueue_style( 'photolog-customizer-sections', get_template_directory_uri() . "/inc/css/customizer-sections.css", '', '20130508' );
		wp_enqueue_script( 'photolog-customizer-sections',	get_template_directory_uri() . '/js/customizer-scripts.js', '', '20160108', true );

		// Add localization strings
	
		$data = array(
			'proURL'	=> esc_url( photolog_get_pro_link( 'customize-head' ) ),
			'proLabel'	=> esc_html__( 'Upgrade to Optics Pro', 'photolog' ),
		);
		// Localize the script
		wp_localize_script(
			'photolog-customizer-sections',
			'photologPro',
			$data
		);
	}

}
add_action( 'customize_controls_enqueue_scripts', 'photolog_customizer_scripts' );
add_action( 'customize_controls_enqueue_scripts', 'photolog_customizer_scripts' );